@@ -6,6 +6,7 @@
 #' @param token Character. Type of token to plot: "point", "id" or "both".
 #' @param text.size Numeric. Size of case ID text.
 #' @param col Character. Color.
+#' @param pos Numeric. Text position.
 #' @export
 #' @examples
 #' snowMap(add.cases = FALSE)
@@ -14,9 +15,8 @@
 #' snowMap(add.cases = FALSE)
 #' addCase(100)
 
-
 addCase <- function(case = 1, type = "observed", token = "both",
-  text.size = 0.5, col = "red") {
+  text.size = 0.5, col = "red", pos = 1) {
 
   if (type %in% c("observed", "expected") == FALSE) {
     stop('type must be "observed" or "expected".')
@@ -32,10 +32,11 @@ addCase <- function(case = 1, type = "observed", token = "both",
     dat <- cholera::regular.cases
   }
 
+  if (pos %in% 1:4 == FALSE) stop("pos must be 1, 2, 3, or 4.")
+  
   if (any(case %in% seq_len(nrow(dat)) == FALSE)) {
     stop('With type = ', type, ', case must be between 1 and ', nrow(dat), ".")
   } else {
-
     if (token == "point") {
       points(dat[case, c("x", "y")], lwd = 2, col = col)
     } else if (token == "id") {
@@ -43,7 +44,7 @@ addCase <- function(case = 1, type = "observed", token = "both",
     } else if (token == "both") {
       points(dat[case, c("x", "y")], lwd = 2, col = col)
       text(dat[case, c("x", "y")], cex = text.size, col = col, labels = case,
-        pos = 1)
+        pos = pos)
     }
   }
 }
