@@ -1,14 +1,8 @@
 #' Add landmarks to plot.
 #'
 #' @param text.size Numeric. cex for text labels.
+#' @param highlight.perimeter Logical. Highlight Lion Brewery and Model Housing.
 #' @note The location of 18 Sackville Street and 28 Dean Street are approximate. Falconberg Court & Mews form an isolate: they are not part of the network of roads and are technically unreachable. Adam and Eve Court and its pump also form an isolate.
-#' @seealso \code{\link{snowMap}},
-#' \code{\link{addIndexCase}},
-#' \code{\link{addKernelDensity}},
-#' \code{\link{addPlaguePit}},
-#' \code{\link{addSnow}},
-#' \code{\link{addVoronoi}},
-#' \code{\link{addWhitehead}}
 #' @return Base R points and text.
 #' @import graphics
 #' @export
@@ -16,9 +10,9 @@
 #' snowMap(add.landmarks = FALSE)
 #' addLandmarks()
 
-addLandmarks <- function(text.size = 0.5) {
+addLandmarks <- function(text.size = 0.5, highlight.perimeter = TRUE) {
   # 28 Dean Street
-  marx <- data.frame(x = 17.3855, y = 13.371 )
+  marx <- data.frame(x = 17.3855, y = 13.371)
   text(marx$x, marx$y, labels = "Karl\nMarx", cex = text.size)
   points(marx$x, marx$y, pch = 15, cex = 1/3)
 
@@ -80,66 +74,29 @@ addLandmarks <- function(text.size = 0.5) {
 
   nm <- c("x", "y")
 
-  # Marlborough Mews: Earl of Aberdeen
-  # NW <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "116-2", c("x2", "y2")], nm)
-  # NE <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "144-1", c("x2", "y2")], nm)
-  # SW <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "161-1", c("x2", "y2")], nm)
-  # SE <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "161-1", c("x1", "y1")], nm)
-  #
-  # aberdeen <- segmentIntersection(NW$x, NW$y, SE$x, SE$y,
-  #                                 NE$x, NE$y, SW$x, SW$y)
-  #
-  # points(aberdeen$x, aberdeen$y, pch = 15, cex = 1/3)
-  # text(aberdeen$x, aberdeen$y, labels = "Earl of\nAberdeen",
-    # cex = text.size)
+  # Argyll House: Earl of Aberdeen
+  # https://www.british-history.ac.uk/survey-london/vols31-2/pt2/pp250-267
+  # https://www.british-history.ac.uk/old-new-london/vol4/pp235-246
+  NW <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
+    "116-2", c("x2", "y2")], nm)
+  NE <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
+    "144-1", c("x2", "y2")], nm)
+  SW <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
+    "161-1", c("x2", "y2")], nm)
+  SE <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
+    "161-1", c("x1", "y1")], nm)
+
+  aberdeen <- segmentIntersection(NW$x, NW$y, SE$x, SE$y,
+                                  NE$x, NE$y, SW$x, SW$y)
+
+  points(aberdeen$x, aberdeen$y, pch = 15, cex = 1/3)
+  text(aberdeen$x, aberdeen$y, labels = "Earl of\nAberdeen",
+    cex = text.size)
 
   # 1) Marlborough Mews: Police Station
 
-  # rd.data <- cholera::road.segments[cholera::road.segments$id == "161-1",
-  #   c("x1", "y1", "x2", "y2")]
-  #
-  # dat <- data.frame(x = unlist(rd.data[, grep("x", names(rd.data))]),
-  #                   y = unlist(rd.data[, grep("y", names(rd.data))]),
-  #                   row.names = NULL)
-  #
-  # ols <- stats::lm(y ~ x, dat)
-  # segment.slope <- stats::coef(ols)[2]
-  # new.int <- aberdeen$y - aberdeen$x * segment.slope
-  # orthogonal.slope <- -1 / segment.slope
-  # orthogonal.intercept <- SW$y - orthogonal.slope * SW$x
-  # new.x <- (orthogonal.intercept - new.int) / (segment.slope - orthogonal.slope)
-  # new.y <- new.x * orthogonal.slope + orthogonal.intercept
-  # points(new.x, new.y, pch = 15, cex = 1/3)
-  # text(new.x, new.y, labels = "Police\nStation", cex = text.size)
-
   # 2) Regent (opposite) at intersection with Little Argyll Street: Chapel
 
-  # text(cholera::road.segments[cholera::road.segments$id == "144-1",
-  #   c("x1", "y1")], labels = "Chapel", pos = 2, cex = text.size)
-
-  # 3) King Street (opposite) at intersection with Cross Street:
-  # Distillery and St James Church
-  # https://maps.nls.uk/os/london-1890s/index.html
-
-  # NW <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "257-1", c("x1", "y1")], nm)
-  # NE <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "305-1", c("x1", "y1")], nm)
-  # SE <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "306-1", c("x1", "y1")], nm)
-  # SW <- stats::setNames(cholera::road.segments[cholera::road.segments$id ==
-  #   "306-1", c("x2", "y2")], nm)
-  #
-  # st.james <- segmentIntersection(NW$x, NW$y, SE$x, SE$y,
-  #                                 NE$x, NE$y, SW$x, SW$y)
-  #
-  # text(st.james$x, st.james$y, labels = "St James\nChurch",
-  #   cex = text.size)
-
   # 4) Oxford Street (opposite) at intersection with Winsley Street:
   # Pantheon Bazaar`
 
@@ -174,8 +131,6 @@ addLandmarks <- function(text.size = 0.5) {
   points(model.lodging$x, model.lodging$y, pch = 15, cex = 1/3)
   text(model.lodging$x, model.lodging$y, labels = "Model\nLodging",
     cex = text.size)
-  # text(model.lodging$x, model.lodging$y, labels = "Model Lodging",
-  #  cex = text.size)
 
   # 7) Marshall Street Public Baths built 1851-2  (Marshall Street)
   # http://www.british-history.ac.uk/survey-london/vols31-2/pt2/pp196-208
@@ -223,4 +178,31 @@ addLandmarks <- function(text.size = 0.5) {
   x.new <- dat[1, "x"] + delta.x
   y.new <- dat[1, "y"] + delta.y
   text(x.new, y.new, labels = "Craven\nChapel", cex = text.size)
+
+  if (highlight.perimeter) {
+    lion.brewery.north <- "187-1"
+    lion.brewery.south <- "225-1"
+    lion.brewery.east <- c("197-1", "215-1")
+    lion.brewery.west <- c("224-1", "226-1")
+
+    model.housing.north <- lion.brewery.south
+    model.housing.south <- "259-1"
+    model.housing.east <- c("245-1", "245-2")
+    model.housing.west <- "259-2"
+
+    brewery <- c(lion.brewery.north, lion.brewery.south, lion.brewery.east,
+      lion.brewery.west)
+    model <- c(model.housing.north, model.housing.south, model.housing.east,
+      model.housing.west)
+    vars <- c("x1", "y1", "x2", "y2")
+
+    landmarkPerimeter <- function(seg.id, col = "dodgerblue", lwd = 2) {
+      lapply(seg.id, function(seg) {
+        dat <- cholera::road.segments[cholera::road.segments$id == seg, vars]
+        segments(dat$x1, dat$y1, dat$x2, dat$y2, col = col, lwd = lwd)
+      })
+    }
+
+    invisible(lapply(c(brewery, model), landmarkPerimeter))
+  }
 }
